@@ -1,18 +1,16 @@
 import os, os.path
 
-import sh
-
-from herokuapp.commands import HerokuCommand
+from herokuapp.commands import HerokuCommand, HerokuCommandError
 
 
 def load_env(entrypoint, app=None):
-    heroku = HerokuCommand(
-        app = app,
-        cwd = os.path.dirname(entrypoint),
-    )
     try:
+        heroku = HerokuCommand(
+            app = app,
+            cwd = os.path.dirname(entrypoint),
+        )
         heroku_config = heroku.config_get()
-    except sh.ErrorReturnCode:
+    except HerokuCommandError:
         pass
     else:
         for key, value in heroku_config.items():
