@@ -20,10 +20,12 @@ SITE_ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
 BASE_DIR = os.path.abspath(os.path.join(SITE_ROOT, ".."))
 
 
-# The name of the app on the Heroku platform.
+# Heroku platform settings.
 
 HEROKU_APP_NAME = "{{ app_name }}"
 
+HEROKU_BUILDPACK_URL = "https://github.com/heroku/heroku-buildpack-python.git"
+
 
 # The name and domain of this site.
 
@@ -81,12 +83,16 @@ AWS_S3_FILE_OVERWRITE = False
 
 AWS_QUERYSTRING_AUTH = False
 
-AWS_S3_SECURE_URLS = False
+AWS_S3_SECURE_URLS = True
 
 AWS_REDUCED_REDUNDANCY = False
 
 AWS_IS_GZIPPED = False
 
+STATIC_URL = "https://{bucket_name}.s3.amazonaws.com/".format(
+    bucket_name = AWS_STORAGE_BUCKET_NAME,
+)
+
 
 # Email settings.
 
